@@ -13,11 +13,13 @@
 // ========================================================================
 
 package com.acme;
+import java.io.BufferedWriter;
 import java.io.IOException;
-import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
+import java.io.Reader;
+import java.lang.reflect.Array;
 import java.lang.reflect.Field;
 import java.util.Enumeration;
 import java.util.Locale;
@@ -33,6 +35,7 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletRequestWrapper;
 import javax.servlet.http.HttpServletResponse;
 
+import org.mortbay.util.StringUtil;
 import org.mortbay.util.ajax.Continuation;
 import org.mortbay.util.ajax.ContinuationSupport;
 
@@ -44,10 +47,18 @@ import org.mortbay.util.ajax.ContinuationSupport;
  */
 public class Dump extends HttpServlet
 {
+    static boolean fixed;
     /* ------------------------------------------------------------ */
     public void init(ServletConfig config) throws ServletException
     {
     	super.init(config);
+    	
+    	if (config.getInitParameter("unavailable")!=null && !fixed)
+    	{
+    	    
+    	    fixed=true;
+    	    throw new UnavailableException("Unavailable test",Integer.parseInt(config.getInitParameter("unavailable")));
+    	}
     }
 
     /* ------------------------------------------------------------ */
@@ -59,6 +70,12 @@ public class Dump extends HttpServlet
     /* ------------------------------------------------------------ */
     public void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException
     {
+        if(request.getPathInfo()!=null && request.getPathInfo().toLowerCase().indexOf("script")!=-1)
+        {
+            response.sendRedirect(getServletContext().getContextPath() + "/dump/info");
+            return;
+        }
+            
         request.setCharacterEncoding("UTF-8");
         
         if (request.getParameter("empty")!=null)
@@ -67,7 +84,7 @@ public class Dump extends HttpServlet
             response.flushBuffer();
             return;
         }
-
+        
         if (request.getParameter("sleep")!=null)
         {
             try
@@ -89,8 +106,15 @@ public class Dump extends HttpServlet
         
         if (request.getParameter("continue")!=null)
         {
-            Continuation continuation = ContinuationSupport.getContinuation(request, null);
-            continuation.suspend(Long.parseLong(request.getParameter("continue")));
+            try
+            {
+                Continuation continuation = ContinuationSupport.getContinuation(request, null);
+                continuation.suspend(Long.parseLong(request.getParameter("continue")));
+            }
+            catch(Exception e)
+            {
+                throw new ServletException(e);
+            }
         }
             
         request.setAttribute("Dump", this);
@@ -174,6 +198,16 @@ public class Dump extends HttpServlet
                 throw new ServletException(th);
             }
         }
+
+        // test a reset
+        String reset= request.getParameter("reset");
+        if (reset != null && reset.length() > 0)
+        {
+            response.getOutputStream().println("THIS SHOULD NOT BE SEEN!");
+            response.setHeader("SHOULD_NOT","BE SEEN");
+            response.reset();
+        }
+        
         
         // handle an redirect
         String redirect= request.getParameter("redirect");
@@ -181,17 +215,36 @@ public class Dump extends HttpServlet
         {
             response.getOutputStream().println("THIS SHOULD NOT BE SEEN!");
             response.sendRedirect(redirect);
-            response.getOutputStream().println("THIS SHOULD NOT BE SEEN!");
+            try
+            {
+                response.getOutputStream().println("THIS SHOULD NOT BE SEEN!");
+            }
+            catch(IOException e)
+            {
+                // ignored as stream is closed.
+            }
             return;
         }
 
         // handle an error
         String error= request.getParameter("error");
-        if (error != null && error.length() > 0)
+        if (error != null && error.length() > 0 && request.getAttribute("javax.servlet.error.status_code")==null)
         {
             response.getOutputStream().println("THIS SHOULD NOT BE SEEN!");
             response.sendError(Integer.parseInt(error));
-            response.getOutputStream().println("THIS SHOULD NOT BE SEEN!");
+            try
+            {
+                response.getOutputStream().println("THIS SHOULD NOT BE SEEN!");
+            }
+            catch(IllegalStateException e)
+            {
+                try
+                {
+                    response.getWriter().println("NOR THIS!!"); 
+                }
+                catch(IOException e2){}
+            }
+            catch(IOException e){}
             return;
         }
 
@@ -222,18 +275,13 @@ public class Dump extends HttpServlet
         }
 
         String cn= request.getParameter("cookie");
-        String cv=request.getParameter("value");
-        String v=request.getParameter("version");
+        String cv=request.getParameter("cookiev");
         if (cn!=null && cv!=null)
         {
             Cookie cookie= new Cookie(cn, cv);
+            if (request.getParameter("version")!=null)
+                cookie.setVersion(Integer.parseInt(request.getParameter("version")));
             cookie.setComment("Cookie from dump servlet");
-            if (v!=null)
-            {
-                cookie.setMaxAge(300);
-                cookie.setPath("/");
-                cookie.setVersion(Integer.parseInt(v));
-            }
             response.addCookie(cookie);
         }
 
@@ -244,13 +292,19 @@ public class Dump extends HttpServlet
             out.write("</H1>This text should be reset</H1>".getBytes());
             if ("/ex0".equals(pi))
                 throw new ServletException("test ex0", new Throwable());
-            if ("/ex1".equals(pi))
+            else if ("/ex1".equals(pi))
                 throw new IOException("test ex1");
-            if ("/ex2".equals(pi))
+            else if ("/ex2".equals(pi))
                 throw new UnavailableException("test ex2");
+            else if (pi.startsWith("/ex3/"))
+                throw new UnavailableException("test ex3",Integer.parseInt(pi.substring(5)));
             throw new RuntimeException("test");
         }
 
+        if ("true".equals(request.getParameter("close")))
+            response.setHeader("Connection","close");
+
+        String buffered= request.getParameter("buffered");
         
         PrintWriter pout=null;
         
@@ -262,43 +316,44 @@ public class Dump extends HttpServlet
         {
             pout=new PrintWriter(new OutputStreamWriter(response.getOutputStream(),charset));
         }
-        
+        if (buffered!=null)
+            pout = new PrintWriter(new BufferedWriter(pout,Integer.parseInt(buffered)));
         
         try
         {
             pout.write("<html>\n<body>\n");
             pout.write("<h1>Dump Servlet</h1>\n");
-            pout.write("<table>");
+            pout.write("<table width=\"95%\">");
             pout.write("<tr>\n");
             pout.write("<th align=\"right\">getMethod:&nbsp;</th>");
-            pout.write("<td>" + request.getMethod()+"</td>");
+            pout.write("<td>" + notag(request.getMethod())+"</td>");
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getContentLength:&nbsp;</th>");
             pout.write("<td>"+Integer.toString(request.getContentLength())+"</td>");
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getContentType:&nbsp;</th>");
-            pout.write("<td>"+request.getContentType()+"</td>");
+            pout.write("<td>"+notag(request.getContentType())+"</td>");
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getRequestURI:&nbsp;</th>");
-            pout.write("<td>"+request.getRequestURI()+"</td>");
+            pout.write("<td>"+notag(request.getRequestURI())+"</td>");
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getRequestURL:&nbsp;</th>");
-            pout.write("<td>"+request.getRequestURL()+"</td>");
+            pout.write("<td>"+notag(request.getRequestURL().toString())+"</td>");
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getContextPath:&nbsp;</th>");
             pout.write("<td>"+request.getContextPath()+"</td>");
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getServletPath:&nbsp;</th>");
-            pout.write("<td>"+request.getServletPath()+"</td>");
+            pout.write("<td>"+notag(request.getServletPath())+"</td>");
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getPathInfo:&nbsp;</th>");
-            pout.write("<td>"+request.getPathInfo()+"</td>");
+            pout.write("<td>"+notag(request.getPathInfo())+"</td>");
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getPathTranslated:&nbsp;</th>");
-            pout.write("<td>"+request.getPathTranslated()+"</td>");
+            pout.write("<td>"+notag(request.getPathTranslated())+"</td>");
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getQueryString:&nbsp;</th>");
-            pout.write("<td>"+request.getQueryString()+"</td>");
+            pout.write("<td>"+notag(request.getQueryString())+"</td>");
 
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getProtocol:&nbsp;</th>");
@@ -308,7 +363,7 @@ public class Dump extends HttpServlet
             pout.write("<td>"+request.getScheme()+"</td>");
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getServerName:&nbsp;</th>");
-            pout.write("<td>"+request.getServerName()+"</td>");
+            pout.write("<td>"+notag(request.getServerName())+"</td>");
             pout.write("</tr><tr>\n");
             pout.write("<th align=\"right\">getServerPort:&nbsp;</th>");
             pout.write("<td>"+Integer.toString(request.getServerPort())+"</td>");
@@ -369,8 +424,8 @@ public class Dump extends HttpServlet
                 {
                     String hv= (String)h2.nextElement();
                     pout.write("</tr><tr>\n");
-                    pout.write("<th align=\"right\">"+name+":&nbsp;</th>");
-                    pout.write("<td>"+hv+"</td>");
+                    pout.write("<th align=\"right\">"+notag(name)+":&nbsp;</th>");
+                    pout.write("<td>"+notag(hv)+"</td>");
                 }
             }
 
@@ -381,13 +436,13 @@ public class Dump extends HttpServlet
             {
                 name= (String)h.nextElement();
                 pout.write("</tr><tr>\n");
-                pout.write("<th align=\"right\">"+name+":&nbsp;</th>");
-                pout.write("<td>"+request.getParameter(name)+"</td>");
+                pout.write("<th align=\"right\">"+notag(name)+":&nbsp;</th>");
+                pout.write("<td>"+notag(request.getParameter(name))+"</td>");
                 String[] values= request.getParameterValues(name);
                 if (values == null)
                 {
                     pout.write("</tr><tr>\n");
-                    pout.write("<th align=\"right\">"+name+" Values:&nbsp;</th>");
+                    pout.write("<th align=\"right\">"+notag(name)+" Values:&nbsp;</th>");
                     pout.write("<td>"+"NULL!"+"</td>");
                 }
                 else if (values.length > 1)
@@ -395,8 +450,8 @@ public class Dump extends HttpServlet
                     for (int i= 0; i < values.length; i++)
                     {
                         pout.write("</tr><tr>\n");
-                        pout.write("<th align=\"right\">"+name+"["+i+"]:&nbsp;</th>");
-                        pout.write("<td>"+values[i]+"</td>");
+                        pout.write("<th align=\"right\">"+notag(name)+"["+i+"]:&nbsp;</th>");
+                        pout.write("<td>"+notag(values[i])+"</td>");
                     }
                 }
             }
@@ -409,27 +464,26 @@ public class Dump extends HttpServlet
                 Cookie cookie = cookies[i];
 
                 pout.write("</tr><tr>\n");
-                pout.write("<th align=\"right\">"+cookie.getName()+":&nbsp;</th>");
-                pout.write("<td>"+cookie.getValue()+"</td>");
+                pout.write("<th align=\"right\">"+notag(cookie.getName())+":&nbsp;</th>");
+                pout.write("<td>"+notag(cookie.getValue())+"</td>");
             }
             
-
-            if (!"application/x-www-form-urlencoded".equals(request.getContentType()))
+            String content_type=request.getContentType();
+            if (content_type!=null &&
+                !content_type.startsWith("application/x-www-form-urlencoded") &&
+                !content_type.startsWith("multipart/form-data"))
             {
                 pout.write("</tr><tr>\n");
                 pout.write("<th align=\"left\" valign=\"top\" colspan=\"2\"><big><br/>Content:</big></th>");
                 pout.write("</tr><tr>\n");
                 pout.write("<td><pre>");
-                byte[] content= new byte[4096];
+                char[] content= new char[4096];
                 int len;
                 try{
-                    InputStream in=request.getInputStream();
+                    Reader in=request.getReader();
                     
                     while((len=in.read(content))>=0)
-                        pout.write(new String(content,0,len));
-                    // int b;
-                    // while ((b=in.read())>=0)
-                    //    pout.write((char)b);
+                        pout.write(notag(new String(content,0,len)));
                 }
                 catch(IOException e)
                 {
@@ -490,22 +544,22 @@ public class Dump extends HttpServlet
             if (res != null && res.length() > 0)
             {
                 pout.write("</tr><tr>\n");
-                pout.write("<th align=\"left\" colspan=\"2\"><big><br/>Get Resource:</big></th>");
+                pout.write("<th align=\"left\" colspan=\"2\"><big><br/>Get Resource: \""+res+"\"</big></th>");
                 
                 pout.write("</tr><tr>\n");
-                pout.write("<th align=\"right\">this.getClass():&nbsp;</th>");
+                pout.write("<th align=\"right\">this.getClass().getResource(...):&nbsp;</th>");
                 pout.write("<td>"+this.getClass().getResource(res)+"</td>");
 
                 pout.write("</tr><tr>\n");
-                pout.write("<th align=\"right\">this.getClass().getClassLoader():&nbsp;</th>");
+                pout.write("<th align=\"right\">this.getClass().getClassLoader().getResource(...):&nbsp;</th>");
                 pout.write("<td>"+this.getClass().getClassLoader().getResource(res)+"</td>");
 
                 pout.write("</tr><tr>\n");
-                pout.write("<th align=\"right\">Thread.currentThread().getContextClassLoader():&nbsp;</th>");
+                pout.write("<th align=\"right\">Thread.currentThread().getContextClassLoader().getResource(...):&nbsp;</th>");
                 pout.write("<td>"+Thread.currentThread().getContextClassLoader().getResource(res)+"</td>");
 
                 pout.write("</tr><tr>\n");
-                pout.write("<th align=\"right\">getServletContext():&nbsp;</th>");
+                pout.write("<th align=\"right\">getServletContext().getResource(...):&nbsp;</th>");
                 try{pout.write("<td>"+getServletContext().getResource(res)+"</td>");}
                 catch(Exception e) {pout.write("<td>"+"" +e+"</td>");}
             }
@@ -563,6 +617,13 @@ public class Dump extends HttpServlet
             pout.write("<input type=\"submit\" name=\"Action\" value=\"Submit\"><br/>");
             pout.write("</form>");
 
+            pout.write("<h2>Form to set Cookie</h2>");
+            pout.write("<form method=\"POST\" action=\""+response.encodeURL(getURI(request))+"\">");
+            pout.write("cookie: <input type=\"text\" name=\"cookie\" /><br/>\n");
+            pout.write("value: <input type=\"text\" name=\"cookiev\" /><br/>\n");
+            pout.write("<input type=\"submit\" name=\"Action\" value=\"setCookie\">");
+            pout.write("</form>\n");
+            
             pout.write("<h2>Form to get Resource</h2>");
             pout.write("<form method=\"POST\" action=\""+response.encodeURL(getURI(request))+"\">");
             pout.write("resource: <input type=\"text\" name=\"resource\" /><br/>\n");
@@ -584,7 +645,17 @@ public class Dump extends HttpServlet
             continuation.suspend(Long.parseLong(request.getParameter("stream")));
         }
 
-
+        String lines= request.getParameter("lines");
+        if (lines!=null)
+        {
+            char[] line = "<span>A line of characters. Blah blah blah blah.  blooble blooble</span></br>\n".toCharArray();
+            for (int l=Integer.parseInt(lines);l-->0;)
+            {
+                pout.write("<span>"+l+" </span>");
+                pout.write(line);
+            }
+        }
+        
         pout.write("</body>\n</html>\n");
         
         pout.close();
@@ -628,24 +699,58 @@ public class Dump extends HttpServlet
         if (o == null)
             return null;
 
-        if (o.getClass().isArray())
+        try
         {
-            StringBuffer sb= new StringBuffer();
-            Object[] array= (Object[])o;
-            for (int i= 0; i < array.length; i++)
+            if (o.getClass().isArray())
             {
-                if (i > 0)
-                    sb.append("\n");
-                sb.append(array.getClass().getComponentType().getName());
-                sb.append("[");
-                sb.append(i);
-                sb.append("]=");
-                sb.append(toString(array[i]));
+                StringBuffer sb = new StringBuffer();
+                if (!o.getClass().getComponentType().isPrimitive())
+                {
+                    Object[] array= (Object[])o;
+                    for (int i= 0; i < array.length; i++)
+                    {
+                        if (i > 0)
+                            sb.append("\n");
+                        sb.append(array.getClass().getComponentType().getName());
+                        sb.append("[");
+                        sb.append(i);
+                        sb.append("]=");
+                        sb.append(toString(array[i]));
+                    }
+                    return sb.toString();
+                }
+                else
+                { 
+                    int length = Array.getLength(o);
+                    for (int i=0;i<length;i++)
+                    {
+                        if (i > 0)
+                            sb.append("\n");
+                        sb.append(o.getClass().getComponentType().getName()); 
+                        sb.append("[");
+                        sb.append(i);
+                        sb.append("]=");
+                        sb.append(toString(Array.get(o, i)));
+                    }
+                    return sb.toString();
+                }
             }
-            return sb.toString();
+            else
+                return o.toString();
+        }
+        catch (Exception e)
+        {
+            return e.toString();
         }
-        else
-            return o.toString();
     }
 
+    private String notag(String s)
+    {
+        if (s==null)
+            return "null";
+        s=StringUtil.replace(s,"&","&amp;");
+        s=StringUtil.replace(s,"<","&lt;");
+        s=StringUtil.replace(s,">","&gt;");
+        return s;
+    }
 }
