@@ -67,7 +67,7 @@ public class ObjectMBean implements DynamicMBean
 {
     private static Class[] OBJ_ARG = new Class[]{Object.class};
 
-    protected Object _managed;
+    private Object _managed;
     private MBeanInfo _info;
     private Map _getters=new HashMap();
     private Map _setters=new HashMap();
@@ -79,6 +79,8 @@ public class ObjectMBean implements DynamicMBean
     private static String OBJECT_NAME_CLASS = ObjectName.class.getName();
     private static String OBJECT_NAME_ARRAY_CLASS = ObjectName[].class.getName();
 
+
+
     /* ------------------------------------------------------------ */
     /**
      * Create MBean for Object. Attempts to create an MBean for the object by searching the package
@@ -172,20 +174,10 @@ public class ObjectMBean implements DynamicMBean
         _loader = Thread.currentThread().getContextClassLoader();
     }
     
-    public Object getManagedObject()
-    {
-        return _managed;
-    }
-    
     public ObjectName getObjectName()
     {
         return null;
     }
-    
-    public String getObjectNameBasis()
-    {
-        return null;
-    }
 
     protected void setMBeanContainer(MBeanContainer container)
     {
@@ -297,6 +289,8 @@ public class ObjectMBean implements DynamicMBean
     /* ------------------------------------------------------------ */
     public Object getAttribute(String name) throws AttributeNotFoundException, MBeanException, ReflectionException
     {
+        if (Log.isDebugEnabled())
+            Log.debug("getAttribute " + name);
         Method getter = (Method) _getters.get(name);
         if (getter == null)
             throw new AttributeNotFoundException(name);
@@ -344,6 +338,7 @@ public class ObjectMBean implements DynamicMBean
     /* ------------------------------------------------------------ */
     public AttributeList getAttributes(String[] names)
     {
+        Log.debug("getAttributes");
         AttributeList results = new AttributeList(names.length);
         for (int i = 0; i < names.length; i++)
         {
@@ -366,7 +361,7 @@ public class ObjectMBean implements DynamicMBean
             return;
 
         if (Log.isDebugEnabled())
-            Log.debug("setAttribute " + _managed + ":" +attr.getName() + "=" + attr.getValue());
+            Log.debug("setAttribute " + attr.getName() + "=" + attr.getValue());
         Method setter = (Method) _setters.get(attr.getName());
         if (setter == null)
             throw new AttributeNotFoundException(attr.getName());
@@ -504,38 +499,31 @@ public class ObjectMBean implements DynamicMBean
      *
      * @param name
      * @param metaData "description" or "access:description" or "type:access:description"  where type is
-     * one of: <ul>
-     * <li>"Object" The field/method is on the managed object.
-     * <li>"MBean" The field/method is on the mbean proxy object
-     * <li>"MObject" The field/method is on the managed object and value should be converted to MBean reference
-     * <li>"MMBean" The field/method is on the mbean proxy object and value should be converted to MBean reference
-     * </ul>
-     * the access is either "RW" or "RO".
+     * the "Object","MBean" or "MObject" to indicate the method is on the object, the MBean or on the object but converted to an MBean, access
+     * is either "RW" or "RO".
      */
     public MBeanAttributeInfo defineAttribute(String name, String metaData)
     {
         String description = "";
-        boolean writable = true;
+        boolean writable = false;
         boolean onMBean = false;
         boolean convert = false;
 
-        if (metaData!= null)
+        String[] tokens = metaData.split(":", 3);
+        if (tokens.length > 0)
         {
-            String[] tokens = metaData.split(":", 3);
-            for (int t=0;t<tokens.length-1;t++)
+            int index = tokens.length - 1;
+            description = tokens[index--];
+            if (index >= 0)
             {
-                tokens[t]=tokens[t].trim();
-                if ("RO".equals(tokens[t]))
-                    writable=false;
-                else 
+                writable = "RW".equalsIgnoreCase(tokens[index--]);
+                if (index >= 0)
                 {
-                    onMBean=("MMBean".equalsIgnoreCase(tokens[t]) || "MBean".equalsIgnoreCase(tokens[t]));
-                    convert=("MMBean".equalsIgnoreCase(tokens[t]) || "MObject".equalsIgnoreCase(tokens[t]));
+                    onMBean = "MMBean".equalsIgnoreCase(tokens[index]) || "MBean".equalsIgnoreCase(tokens[index]);
+                    convert = "MMBean".equalsIgnoreCase(tokens[index]) || "MObject".equalsIgnoreCase(tokens[index]);
                 }
             }
-            description=tokens[tokens.length-1];
         }
-        
 
         String uName = name.substring(0, 1).toUpperCase() + name.substring(1);
         Class oClass = onMBean ? this.getClass() : _managed.getClass();
@@ -585,7 +573,7 @@ public class ObjectMBean implements DynamicMBean
                 type = methods[m].getParameterTypes()[0];
             }
         }
-        
+
         if (convert && type.isPrimitive() && !type.isArray())
             throw new IllegalArgumentException("Cannot convert primative " + name);
 
@@ -629,24 +617,22 @@ public class ObjectMBean implements DynamicMBean
      * Define an operation on the managed object. Defines an operation with parameters. Refection is
      * used to determine find the method and it's return type. The description of the method is
      * found with a call to findDescription on "name(signature)". The name and description of each
-     * parameter is found with a call to findDescription with "name(signature)[n]", the returned
+     * parameter is found with a call to findDescription with "name(partialSignature", the returned
      * description is for the last parameter of the partial signature and is assumed to start with
      * the parameter name, followed by a colon.
      *
      * @param metaData "description" or "impact:description" or "type:impact:description", type is
-     * the "Object","MBean", "MMBean" or "MObject" to indicate the method is on the object, the MBean or on the
-     * object but converted to an MBean reference, and impact is either "ACTION","INFO","ACTION_INFO" or "UNKNOWN".
+     * the "Object","MBean" or "MObject" to indicate the method is on the object, the MBean or on the
+     * object but converted to an MBean, and impact is either "ACTION","INFO","ACTION_INFO" or "UNKNOWN".
      */
     private MBeanOperationInfo defineOperation(String signature, String metaData, ResourceBundle bundle)
     {
         String[] tokens=metaData.split(":",3);
         int i=tokens.length-1;
         String description=tokens[i--];
-        String impact_name = i<0?"UNKNOWN":tokens[i--].trim();
-        if (i==0)
-            tokens[0]=tokens[0].trim();
-        boolean onMBean= i==0 && ("MBean".equalsIgnoreCase(tokens[0])||"MMBean".equalsIgnoreCase(tokens[0]));
-        boolean convert= i==0 && ("MObject".equalsIgnoreCase(tokens[0])||"MMBean".equalsIgnoreCase(tokens[0]));
+        String impact_name = i<0?"UNKNOWN":tokens[i--];
+        boolean onMBean= i==0 && "MBean".equalsIgnoreCase(tokens[0]);
+        boolean convert= i==0 && "MObject".equalsIgnoreCase(tokens[0]);
 
         if (Log.isDebugEnabled())
             Log.debug("defineOperation "+signature+" "+onMBean+":"+impact_name+":"+description);
